@@ -101,12 +101,21 @@ def func_downloaddata_bybatch(fpath_cfg, nm_table, flag_mute = 0, batch_size = 1
         limit {batch_size}
         offset {i}
         '''.format(tbnm_from = nm_table, batch_size = batch_size, i = cur_i)
-        with odps.execute_sql(str_sql_exe).open_reader() as reader:
-            dft = reader.to_pandas()
-            if flag_mute == 0:
-                rn = dft.shape[0]
-                print('start at {cur_i}, finish number of rows {rn}'.format(cur_i = cur_i, rn = rn))
-            data.append(dft)
+        retry_i = 0
+        while retry_i <= 3:
+            retry_i += 1
+            try:
+                with odps.execute_sql(str_sql_exe).open_reader() as reader:
+                    dft = reader.to_pandas()
+                    if flag_mute == 0:
+                        rn = dft.shape[0]
+                        print('start at {cur_i}, finish number of rows {rn}'.format(cur_i = cur_i, rn = rn))
+                    data.append(dft)
+            except:
+                if retry_i <= 2:
+                    print('retry {} failed'.format(retry_i))
+                else:
+                    raise
 
     import pandas as pd
     df_r = pd.concat(data, ignore_index = True, axis = 0)
